/*
Module : EZView.h
Purpose: Defines the CWinApp class for EZView

Copyright (c) 2000 - 2022 by PJ Naughter (Web: www.naughter.com, Email: pjna@naughter.com)

All rights reserved.

Copyright / Usage Details:

You are allowed to include the source code in any product (commercial, shareware, freeware or otherwise)
when your product is released in binary form. You are allowed to modify the source code in any way you want
except you cannot modify the copyright details at the top of each module. If you want to distribute source
code with your application, then you are only allowed to distribute versions released by the author. This is
to maintain a single distribution point for the source code.

*/


//////////////////// Macros / Defines /////////////////////////////////////////

#ifndef __AFXWIN_H__
  #error include 'stdafx.h' before including this file for PCH
#endif //#ifndef __AFXWIN_H__


//////////////////// Includes /////////////////////////////////////////////////

#include "resource.h"
#include "EZViewDoc.h"
#include "MainFrm.h"


//////////////////// Classes //////////////////////////////////////////////////

class CMyRecentFileList : public CRecentFileList
{
public: 
//Constructors / Destructors
  CMyRecentFileList(UINT nStart, LPCTSTR lpszSection, LPCTSTR lpszEntryFormat, int nSize, int nMaxDispLen = AFX_ABBREV_FILENAME_LEN);
  CMyRecentFileList(const CMyRecentFileList&) = delete;
  CMyRecentFileList(CMyRecentFileList&&) = delete;
  ~CMyRecentFileList() = default; //NOLINT(modernize-use-override)

//Methods
  CMyRecentFileList& operator=(const CMyRecentFileList&) = delete;
  CMyRecentFileList& operator=(CMyRecentFileList&&) = delete;
  void UpdateMenu(CCmdUI* pCmdUI) override;
};

class CEZViewApp : public CWinAppEx
{
public:
//Constructors / Destructors
  CEZViewApp();
  CEZViewApp(const CEZViewApp&) = delete;
  CEZViewApp(CEZViewApp&&) = delete;
  ~CEZViewApp() = default; //NOLINT(modernize-use-override)

//Methods
  CEZViewApp& operator=(const CEZViewApp&) = delete;
  CEZViewApp& operator=(CEZViewApp&&) = delete;
  void RefreshImageList(_In_ const CString& sFolder);
  void RefreshImageList2(_In_ const CString& sPath);
  void AddToRecentFolderList(_In_z_ LPCTSTR lpszPathName);
  bool OpenDocumentFolder(_In_ const CString& sDir);
  void AddToRecentFileList(_In_z_ LPCTSTR lpszPathName) override;
  CDocument* OpenDocumentFile(LPCTSTR lpszFileName) override;
  CDocument* OpenNextDocumentFile();
  CDocument* OpenPrevDocumentFile();
  CDocument* OpenDocumentFile(_In_ int nImageIndex); //NOLINT(clang-diagnostic-overloaded-virtual)

//Member variables
  int m_nCurrentImageIndex;
  std::vector<CString> m_ImagesInCurrentFolder;
  bool m_bPromptStartEndFolder;
  bool m_bHideCursorDuringFullScreen;
  bool m_bMessageBoxUp;
  int m_nSlideshowInterval;
  bool m_bShowFilenameDuringFullScreen;
  COLORREF m_FullScreenTextColor;
  COLORREF m_FullScreenBackgroundColor;
  bool m_bAskMeOnDelete;
  bool m_bSizeToFit;
  bool m_bAutoRotate;

protected:
//Member variables
  CMyRecentFileList m_RecentFolderList;
  CMyRecentFileList m_RecentFileList;
  CString m_sFileExtensions;
  std::vector<CString> m_sSupportedExtensions;

//Methods
  bool CanDisplayFile(_In_ const CString& sFilename);
  BOOL InitInstance() override;
  int ExitInstance() override;
  void WinHelp(DWORD_PTR dwData, UINT nCmd = HELP_CONTEXT) override;
  void LoadUserSettings();
  void SaveUserSettings();
  int DoMessageBox(LPCTSTR lpszPrompt, UINT nType, UINT nIDPrompt) override;
  void GenerateFileExtensionsString();

//Message handlers
  afx_msg void OnAppAbout();
  afx_msg void OnFileOpen();
  afx_msg void OnFileOpenFolder();
  afx_msg void OnUpdateRecentFolderMenu(CCmdUI* pCmdUI);
  afx_msg BOOL OnOpenRecentFolder(UINT nID);
  afx_msg void OnUpdateRecentFileMenu(CCmdUI* pCmdUI);
  afx_msg BOOL OnOpenRecentFile(UINT nID);
  afx_msg void OnToolsOptions();
  afx_msg void OnHelpIndex();
  afx_msg void OnHelp();

  DECLARE_MESSAGE_MAP()
};

class CAboutDlg : public CDialog
{
public:
//Constructors / Destructors
  CAboutDlg();
  CAboutDlg(const CAboutDlg&) = delete;
  CAboutDlg(CAboutDlg&&) = delete;
  ~CAboutDlg() = default; //NOLINT(modernize-use-override)

//Methods
  CAboutDlg& operator=(const CAboutDlg&) = delete;
  CAboutDlg& operator=(CAboutDlg&&) = delete;

//Member variables
  enum { IDD = IDD_ABOUTBOX };

protected:
  DECLARE_MESSAGE_MAP()
};

//Helper externs / functions
extern CEZViewApp theApp;
CMainFrame* GetMainFrame();
